@@ -18,7 +18,7 @@ static int ifcore_list(lua_State *lua);
 static int ifcore_lsub(lua_State *lua);
 static int ifcore_fetchfast(lua_State *lua);
 static int ifcore_fetchheader(lua_State *lua);
-static int ifcore_fetchbody(lua_State *lua);
+static int ifcore_fetchtext(lua_State *lua);
 static int ifcore_fetchfields(lua_State *lua);
 static int ifcore_store(lua_State *lua);
 static int ifcore_copy(lua_State *lua);
@@ -37,8 +37,17 @@ static const luaL_reg ifcorelib[] = {
 	{ "lsub", ifcore_lsub },
 	{ "search", ifcore_search },
 	{ "fetchfast", ifcore_fetchfast },
+
+	/*
+	 * RFC 822: message == header + body
+	 * RFC 3501: body == header + text
+	 * 
+	 * RFC 3501 notation is used internally, and RFC 822 notation is used
+	 * for the interface available to the user.
+	 */
 	{ "fetchheader", ifcore_fetchheader },
-	{ "fetchbody", ifcore_fetchbody },
+	{ "fetchbody", ifcore_fetchtext }, 
+
 	{ "fetchfields", ifcore_fetchfields },
 	{ "store", ifcore_store },
 	{ "copy", ifcore_copy },
@@ -97,7 +106,7 @@ ifcore_login(lua_State *lua)
 	if (!(p = get_table_string("password")))
 		luaL_error(lua, "no password specified");
 
-	r = request_login(s, u, p, (unsigned int)(get_table_number("port")),
+	r = request_login(s, u, p, get_table_string("port"),
 	    get_table_string("ssl"));
 
 	lua_pop(lua, 1);
@@ -426,7 +435,7 @@ ifcore_fetchheader(lua_State *lua)
 	const char *s, *u;
 	int r;
 	char *header;
-	unsigned long int len;
+	size_t len;
 
 	header = NULL;
 	len = 0;
@@ -460,17 +469,17 @@ ifcore_fetchheader(lua_State *lua)
 
 
 /*
- * Core function to fetch message body.
+ * Core function to fetch message text.
  */
 static int
-ifcore_fetchbody(lua_State *lua)
+ifcore_fetchtext(lua_State *lua)
 {
 	const char *s, *u;
 	int r;
-	char *body;
-	unsigned long int len;
+	char *text;
+	size_t len;
 
-	body = NULL;
+	text = NULL;
 	len = 0;
 
 	if (lua_gettop(lua) != 2)
@@ -486,16 +495,16 @@ ifcore_fetchbody(lua_State *lua)
 		luaL_error(lua, "no username specified");
 	lua_pop(lua, 1);
 
-	r = request_fetchbody(s, u, lua_tostring(lua, 2), &body, &len);
+	r = request_fetchtext(s, u, lua_tostring(lua, 2), &text, &len);
 
 	lua_pop(lua, 2);
 
 	lua_pushboolean(lua, (r == STATUS_RESPONSE_OK));
 
-	if (!body)
+	if (!text)
 		return 1;
 
-	lua_pushlstring(lua, body, len);
+	lua_pushlstring(lua, text, len);
 
 	return 2;
 }
@@ -510,7 +519,7 @@ ifcore_fetchfields(lua_State *lua)
 	const char *s, *u;
 	int r;
 	char *fields;
-	unsigned long int len;
+	size_t len;
 
 	fields = NULL;
 	len = 0;
@@ -647,7 +656,7 @@ ifcore_append(lua_State *lua)
 	lua_pop(lua, 1);
 
 	r = request_append(s, u, lua_tostring(lua, 2), lua_tostring(lua, 3),
-	    lua_tostring(lua, 4), lua_tostring(lua, 5));
+	    lua_strlen(lua, 3), lua_tostring(lua, 4), lua_tostring(lua, 5));
 
 	lua_pop(lua, lua_gettop(lua));
 
