@@ -72,18 +72,28 @@ prepare_command(const char *fmt,...)
  * Send a response to a command continuation request.
  */
 int
-imap_continuation(session *ssn, const char *cont)
+imap_continuation(session *ssn, const char *cont, size_t len)
 {
 
 	if (ssn->socket == -1)
 		return -1;
 
 
-	if (socket_write(ssn, cont, strlen(cont)) == -1 ||
+	if (socket_write(ssn, cont, len) == -1 ||
 	    socket_write(ssn, "\r\n", strlen("\r\n")) == -1)
 		return -1;
 
-	debug("sending continuation data (%d):\n\n%s\r\n\n", ssn->socket, cont);
+	if (opts.debug > 0) {
+		int i;
+
+		debug("sending continuation data (%d):\n\n", ssn->socket);
+		
+		for (i = 0; i < len; i++)
+			debugc(cont[i]);
+		
+		debug("\r\n\n");
+			
+	}
 
 	return 0;
 }
