@@ -94,7 +94,7 @@ int create_file(char *fname, mode_t mode);
 int get_pathmax(void);
 
 /*	imap.c		*/
-int imap_continuation(session *ssn, const char *cont);
+int imap_continuation(session *ssn, const char *cont, size_t len);
 int imap_capability(session *ssn);
 int imap_noop(session *ssn);
 int imap_logout(session *ssn);
@@ -125,6 +125,7 @@ int imap_namespace(session *ssn);
 /*	log.c		*/
 void verbose(const char *info,...);
 void debug(const char *debug,...);
+void debugc(char c);
 void error(const char *errmsg,...);
 void fatal(unsigned int errnum, const char *fatal,...);
 
@@ -169,7 +170,7 @@ const char *reverse_namespace(const char *mbox, char *prefix, char delim);
 /*	request.c	*/
 int request_noop(const char *server, const char *user);
 int request_login(const char *server, const char *user, const char *pass,
-    unsigned int port, const char *ssl);
+    const char *port, const char *ssl);
 int request_logout(const char *server, const char *user);
 int request_status(const char *server, const char *user, const char *mbox,
     unsigned int *exist, unsigned int *recent, unsigned int *unseen);
@@ -184,18 +185,17 @@ int request_search(const char *server, const char *user, const char *criteria,
 int request_fetchfast(const char *server, const char *user, const char *mesg,
     char **flags, char **date, char **size);
 int request_fetchheader(const char *server, const char *user, const char *mesg,
-    char **header, unsigned long int *len);
-int request_fetchbody(const char *server, const char *user, const char *mesg,
-    char **body, unsigned long int *len);
+    char **header, size_t *len);
+int request_fetchtext(const char *server, const char *user, const char *mesg,
+    char **text, size_t *len);
 int request_fetchfields(const char *server, const char *user,
-    const char *mesg, const char *headerfields, char **fields,
-    unsigned long int *len);
+    const char *mesg, const char *headerfields, char **fields, size_t *len);
 int request_store(const char *server, const char *user, const char *mesg,
     const char *mode, const char *flags);
 int request_copy(const char *server, const char *user, const char *mesg,
     const char *mbox);
 int request_append(const char *server, const char *user, const char *mbox,
-    const char *mesg, const char *flags, const char *date);
+    const char *mesg, size_t mesglen, const char *flags, const char *date);
 
 /*	response.c	*/
 int response_generic(session *ssn, int tag);
@@ -209,31 +209,28 @@ int response_examine(session *ssn, int tag, unsigned int *exist,
     unsigned int *recent);
 int response_select(session *ssn, int tag);
 int response_list(session *ssn, int tag, char **mboxs, char **folders);
-int response_lsub(session *ssn, int tag, char **mboxs, char **folders);
 int response_search(session *ssn, int tag, char **mesgs);
 int response_fetchfast(session *ssn, int tag, char **flags, char **date,
     char **size);
-int response_fetchheader(session *ssn, int tag, char **header,
-    unsigned long int *len);
-int response_fetchbody(session *ssn, int tag, char **body,
-    unsigned long int *len);
-int response_fetchfields(session *ssn, int tag, char **fields,
-    unsigned long int *len);
+int response_fetchbody(session *ssn, int tag, char **body, size_t *len);
 
 /*	signal.c	*/
 void catch_signals(void);
 void release_signals(void);
 
 /*	socket.c	*/
-int open_connection(session *ssn, const char *server, unsigned int port,
-    const char *sprotocol);
+int open_connection(session *ssn, const char *server, const char *port,
+    const char *protocol);
 int close_connection(session *ssn);
-#ifndef NO_SSLTLS
-int open_secure_connection(session *ssn, const char *protocol);
-int close_secure_connection(session *ssn);
-#endif
 ssize_t socket_read(session *ssn, char *buf, size_t len);
 ssize_t socket_write(session *ssn, const char *buf, size_t len);
+#ifndef NO_SSLTLS
+int open_secure_connection(session *ssn, const char *server, const char *port,
+    const char *protocol);
+int close_secure_connection(session *ssn);
+ssize_t socket_secure_read(session *ssn, char *buf, size_t len);
+ssize_t socket_secure_write(session *ssn, const char *buf, size_t len);
+#endif
 
 /*	system.c	*/
 LUALIB_API int luaopen_ifsys(lua_State *lua);
