@@ -3,10 +3,10 @@
 
 #include "imapfilter.h"
 #include "session.h"
-#include "queue.h"
+#include "list.h"
 
 
-extern struct sessionhead sessions;
+extern list *sessions;
 
 
 /*
@@ -17,11 +17,11 @@ session_new(void)
 {
 	session *s;
 
-	s = (session *) xmalloc(sizeof(session));
+	s = (session *)xmalloc(sizeof(session));
 
 	session_init(s);
 
-	XLIST_INSERT_HEAD(&sessions, s, links);
+	sessions = list_append(sessions, s);
 
 	return s;
 }
@@ -31,8 +31,9 @@ session_new(void)
  * Set session variables to safe values.
  */
 void
-session_init(session * ssn)
+session_init(session *ssn)
 {
+
 	ssn->server = NULL;
 	ssn->username = NULL;
 	ssn->socket = -1;
@@ -50,9 +51,10 @@ session_init(session * ssn)
  * Remove session from sessions linked list.
  */
 void
-session_destroy(session * ssn)
+session_destroy(session *ssn)
 {
-	XLIST_REMOVE(ssn, links);
+
+	sessions = list_remove(sessions, ssn);
 
 	session_free(ssn);
 }
@@ -62,7 +64,7 @@ session_destroy(session * ssn)
  * Free session allocated memory.
  */
 void
-session_free(session * ssn)
+session_free(session *ssn)
 {
 
 	if (ssn->server)
@@ -81,12 +83,15 @@ session_free(session * ssn)
 session *
 session_find(const char *serv, const char *user)
 {
+	list *l;
 	session *s;
 
-	XLIST_FOREACH(s, &sessions, links)
-	    if (!strncmp(s->server, serv, strlen(serv)) &&
-	    !strncmp(s->username, user, strlen(user)))
-		break;
+	for (l = sessions; l; l = l->next) {
+		s = l->data;
+		if (!strncmp(s->server, serv, strlen(serv)) &&
+		    !strncmp(s->username, user, strlen(user)))
+			return s;
+	}
 
-	return s;
+	return NULL;
 }
