@@ -2,16 +2,11 @@
 #define SESSION_H
 
 
-#include "queue.h"
-
 #ifndef NO_SSLTLS
 #include <openssl/ssl.h>
 #endif
 
 
-/* IMAP sessions list head. */
-XLIST_HEAD(sessionhead, session);
-
 /* IMAP session. */
 typedef struct session {
 	char *server;		/* Server hostname. */
@@ -27,15 +22,14 @@ typedef struct session {
 		char *prefix;	/* Namespace prefix. */
 		char delim;	/* Namespace delimiter. */
 	} ns;
-	 XLIST_ENTRY(session) links;
 } session;
 
 
 /*	session.c	*/
 session *session_new(void);
-void session_init(session * ssn);
-void session_destroy(session * ssn);
-void session_free(session * ssn);
+void session_init(session *ssn);
+void session_destroy(session *ssn);
+void session_free(session *ssn);
 session *session_find(const char *server, const char *user);
 
 
